@@ -96,7 +96,7 @@ main (int argc, char **argv)
 
 	/* Browser config */
 	config = g_new0 (BrowserConfig, 1);
-	dictionary = GDA_DICT (gda_dict_new ());
+	dictionary = gda_dict_new ();
 	config->dict = dictionary;
 	config->client = gda_client_new ();
 	gda_dict_extend_with_functions (config->dict);
@@ -394,7 +394,7 @@ update_dbms_data_cb (GtkWidget *wid, BrowserConfig *config)
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG(dlg)->vbox), updview, TRUE, TRUE, 0);
 	gtk_widget_show (dlg);
 
-	if (!gda_dict_update_dbms_data (config->dict, 0, NULL, &error)) {
+	if (!gda_dict_update_dbms_meta_data (config->dict, 0, NULL, &error)) {
 		if (error->code != GDA_DICT_META_DATA_UPDATE_USER_STOPPED) {
 			GtkWidget *msg;
 			
@@ -432,7 +432,7 @@ update_dbms_data_cb (GtkWidget *wid, BrowserConfig *config)
 static void
 stop_dbms_update_cb (GtkWidget *dlg, gint response, BrowserConfig *config)
 {
-	gda_dict_stop_update_dbms_data (config->dict);
+	gda_dict_stop_update_dbms_meta_data (config->dict);
 }
 
 static void
@@ -584,7 +584,7 @@ function_get_args (GdaDictFunction *func)
 	gboolean firstarg = TRUE;
 
 	string = g_string_new ("");
-	args = gda_dict_function_get_arg_types (func);
+	args = gda_dict_function_get_arg_dict_types (func);
 	g_string_append (string, " (");
 	while (args) {
 		if (firstarg)
@@ -636,13 +636,13 @@ dt_selection_changed_cb (GnomeDbSelector *mgsel, GObject *dt, BrowserConfig *con
 			switch (config->dt_mode) {
 			case 0:
 				if (GDA_IS_DICT_FUNCTION (list->data)) {
-					ldt = gda_dict_function_get_ret_type (GDA_DICT_FUNCTION (list->data));
+					ldt = gda_dict_function_get_ret_dict_type (GDA_DICT_FUNCTION (list->data));
 					getfunc = (G_OBJECT (ldt) == dt) ? TRUE : FALSE;
 				}
 				break;
 			case 1:
 				if (GDA_IS_DICT_FUNCTION (list->data)) {
-					args = (GSList *) gda_dict_function_get_arg_types (GDA_DICT_FUNCTION (list->data));
+					args = (GSList *) gda_dict_function_get_arg_dict_types (GDA_DICT_FUNCTION (list->data));
 					while (args && !getfunc) {
 						if (args->data == (gpointer) dt)
 							getfunc = TRUE;
@@ -652,7 +652,7 @@ dt_selection_changed_cb (GnomeDbSelector *mgsel, GObject *dt, BrowserConfig *con
 				break;
 			case 2:
 				if (GDA_IS_DICT_AGGREGATE (list->data)) {
-					ldt = gda_dict_aggregate_get_arg_type (GDA_DICT_AGGREGATE (list->data));
+					ldt = gda_dict_aggregate_get_arg_dict_type (GDA_DICT_AGGREGATE (list->data));
 					getfunc = !ldt || (G_OBJECT (ldt) == dt) ? TRUE : FALSE;
 				}
 				break;
@@ -670,7 +670,7 @@ dt_selection_changed_cb (GnomeDbSelector *mgsel, GObject *dt, BrowserConfig *con
 				if (GDA_IS_DICT_FUNCTION (list->data))
 					str = function_get_args (GDA_DICT_FUNCTION (list->data));
 				else {
-					if ((ldt = gda_dict_aggregate_get_arg_type (GDA_DICT_AGGREGATE (list->data)))) {
+					if ((ldt = gda_dict_aggregate_get_arg_dict_type (GDA_DICT_AGGREGATE (list->data)))) {
 						str = g_strdup_printf (" (%s)", gda_object_get_name (GDA_OBJECT (ldt)));
 					}
 					else
@@ -1055,14 +1055,14 @@ table_view_contents (GtkWidget *button, BrowserConfig *config)
 		GdaDataModel *query_model;
 
 		/* Query preparation: "SELECT * FROM table" */
-		query = GDA_QUERY (gda_query_new (config->dict));
+		query = gda_query_new (config->dict);
 		gda_query_set_query_type (query, GDA_QUERY_TYPE_SELECT);
 		
-		target = GDA_QUERY_TARGET (gda_query_target_new (query, gda_object_get_name (GDA_OBJECT (table))));
+		target = gda_query_target_new (query, gda_object_get_name (GDA_OBJECT (table)));
 		gda_query_add_target (query, target, NULL);
 		g_object_unref (G_OBJECT (target));
 		
-		field = GDA_QUERY_FIELD (gda_query_field_all_new (query, gda_object_get_name (GDA_OBJECT (table))));;
+		field = gda_query_field_all_new (query, gda_object_get_name (GDA_OBJECT (table)));
 		gda_entity_add_field (GDA_ENTITY (query), GDA_ENTITY_FIELD (field));
 		g_object_unref (G_OBJECT (field));
 		
@@ -1081,10 +1081,10 @@ table_view_contents (GtkWidget *button, BrowserConfig *config)
 			GSList *table_field_list, *list;
 			gint i = 0;
 			
-			query_ins = GDA_QUERY (gda_query_new (config->dict));
+			query_ins = gda_query_new (config->dict);
 			gda_query_set_query_type (query_ins, GDA_QUERY_TYPE_INSERT);
 			
-			target = GDA_QUERY_TARGET (gda_query_target_new (query_ins, gda_object_get_name (GDA_OBJECT (table))));
+			target = gda_query_target_new (query_ins, gda_object_get_name (GDA_OBJECT (table)));
 			gda_query_add_target (query_ins, target, NULL);
 			
 			table_field_list = gda_entity_get_fields (GDA_ENTITY(table));
@@ -1109,8 +1109,8 @@ table_view_contents (GtkWidget *button, BrowserConfig *config)
 				gda_entity_add_field (GDA_ENTITY (query_ins), GDA_ENTITY_FIELD (qfieldfield));
 
 				/* value query field */
-				qfieldvalue = GDA_QUERY_FIELD_VALUE (gda_query_field_value_new (query_ins, 
-								     gda_entity_field_get_gda_type (GDA_ENTITY_FIELD (tfield))));
+				qfieldvalue = (GdaQueryFieldValue *) gda_query_field_value_new (query_ins, 
+								     gda_entity_field_get_g_type (GDA_ENTITY_FIELD (tfield)));
 				gda_query_field_set_visible (GDA_QUERY_FIELD (qfieldvalue), FALSE);
 				str = g_strdup_printf ("+%d", i++);
 				gda_object_set_name (GDA_OBJECT (qfieldvalue), str);
@@ -1144,13 +1144,13 @@ table_view_contents (GtkWidget *button, BrowserConfig *config)
 			GdaQueryCondition *cond, *newcond;
 			gboolean has_pk;
 			
-			query_upd = GDA_QUERY (gda_query_new (config->dict));
+			query_upd = gda_query_new (config->dict);
 			gda_query_set_query_type (query_upd, GDA_QUERY_TYPE_UPDATE);
 			
-			target = GDA_QUERY_TARGET (gda_query_target_new (query_upd, gda_object_get_name (GDA_OBJECT (table))));
+			target = gda_query_target_new (query_upd, gda_object_get_name (GDA_OBJECT (table)));
 			gda_query_add_target (query_upd, target, NULL);
 
-			cond = GDA_QUERY_CONDITION (gda_query_condition_new(query_upd, GDA_QUERY_CONDITION_NODE_AND));
+			cond = gda_query_condition_new(query_upd, GDA_QUERY_CONDITION_NODE_AND);
 
 			has_pk = gda_dict_table_get_pk_constraint (table) ? TRUE : FALSE;
 
@@ -1177,7 +1177,7 @@ table_view_contents (GtkWidget *button, BrowserConfig *config)
 					
 				/* value query field */
 				qfieldvalue = GDA_QUERY_FIELD_VALUE (gda_query_field_value_new (query_upd, 
-												gda_entity_field_get_gda_type (GDA_ENTITY_FIELD (tfield))));
+												gda_entity_field_get_g_type (GDA_ENTITY_FIELD (tfield))));
 				gda_query_field_set_visible (GDA_QUERY_FIELD (qfieldvalue), FALSE);
 				str = g_strdup_printf ("+%d", i);
 				gda_object_set_name (GDA_OBJECT (qfieldvalue), str);
@@ -1196,7 +1196,7 @@ table_view_contents (GtkWidget *button, BrowserConfig *config)
 
 					/* condition value query field */
 					qfieldvalue = GDA_QUERY_FIELD_VALUE (gda_query_field_value_new (query_upd, 
-													gda_entity_field_get_gda_type (GDA_ENTITY_FIELD (tfield))));
+													gda_entity_field_get_g_type (GDA_ENTITY_FIELD (tfield))));
 					gda_query_field_set_visible (GDA_QUERY_FIELD (qfieldvalue), FALSE);
 					str = g_strdup_printf ("-%d", i);
 					gda_object_set_name (GDA_OBJECT (qfieldvalue), str);
@@ -1208,7 +1208,7 @@ table_view_contents (GtkWidget *button, BrowserConfig *config)
 					gda_query_field_value_set_default_value (GDA_QUERY_FIELD_VALUE (qfieldvalue), 
 										 gda_dict_field_get_default_value (tfield));
 
-					newcond = GDA_QUERY_CONDITION (gda_query_condition_new(query_upd, GDA_QUERY_CONDITION_LEAF_EQUAL));
+					newcond = gda_query_condition_new(query_upd, GDA_QUERY_CONDITION_LEAF_EQUAL);
 
 					gda_query_condition_leaf_set_operator (newcond, GDA_QUERY_CONDITION_OP_LEFT, GDA_QUERY_FIELD (qfieldfield));
 					gda_query_condition_leaf_set_operator (newcond, GDA_QUERY_CONDITION_OP_RIGHT, GDA_QUERY_FIELD (qfieldvalue));
@@ -1253,13 +1253,13 @@ table_view_contents (GtkWidget *button, BrowserConfig *config)
 			GdaQueryCondition *cond, *newcond;
 			gboolean has_pk;
 			
-			query_del = GDA_QUERY (gda_query_new (config->dict));
+			query_del = gda_query_new (config->dict);
 			gda_query_set_query_type (query_del, GDA_QUERY_TYPE_DELETE);
 			
-			target = GDA_QUERY_TARGET (gda_query_target_new (query_del, gda_object_get_name (GDA_OBJECT (table))));
+			target = gda_query_target_new (query_del, gda_object_get_name (GDA_OBJECT (table)));
 			gda_query_add_target (query_del, target, NULL);
 
-			cond = GDA_QUERY_CONDITION (gda_query_condition_new(query_del, GDA_QUERY_CONDITION_NODE_AND));
+			cond = gda_query_condition_new(query_del, GDA_QUERY_CONDITION_NODE_AND);
 
 			has_pk = gda_dict_table_get_pk_constraint (table) ? TRUE : FALSE;
 
@@ -1288,7 +1288,7 @@ table_view_contents (GtkWidget *button, BrowserConfig *config)
 
 					/* condition value query field */
 					qfieldvalue = GDA_QUERY_FIELD_VALUE (gda_query_field_value_new (query_del, 
-													gda_entity_field_get_gda_type (GDA_ENTITY_FIELD (tfield))));
+													gda_entity_field_get_g_type (GDA_ENTITY_FIELD (tfield))));
 					gda_query_field_set_visible (GDA_QUERY_FIELD (qfieldvalue), FALSE);
 					str = g_strdup_printf ("-%d", i);
 					gda_object_set_name (GDA_OBJECT (qfieldvalue), str);
@@ -1301,7 +1301,7 @@ table_view_contents (GtkWidget *button, BrowserConfig *config)
 										 gda_dict_field_get_default_value (tfield));
 				        g_object_set (qfieldfield, "value-provider", qfieldvalue, NULL);
 
-					newcond = GDA_QUERY_CONDITION (gda_query_condition_new(query_del, GDA_QUERY_CONDITION_LEAF_EQUAL));
+					newcond = gda_query_condition_new(query_del, GDA_QUERY_CONDITION_LEAF_EQUAL);
 
 					gda_query_condition_leaf_set_operator (newcond, GDA_QUERY_CONDITION_OP_LEFT, GDA_QUERY_FIELD (qfieldfield));
 					gda_query_condition_leaf_set_operator (newcond, GDA_QUERY_CONDITION_OP_RIGHT, GDA_QUERY_FIELD (qfieldvalue));
