@@ -124,7 +124,7 @@ gnome_db_entry_cidr_new (GdaDataHandler *dh, GType type)
 
 	g_return_val_if_fail (dh && GDA_IS_DATA_HANDLER (dh), NULL);
 	g_return_val_if_fail (type != G_TYPE_INVALID, NULL);
-	g_return_val_if_fail (gda_data_handler_accepts_gda_type (dh, type), NULL);
+	g_return_val_if_fail (gda_data_handler_accepts_g_type (dh, type), NULL);
 
 	obj = g_object_new (GNOME_DB_TYPE_ENTRY_CIDR, "handler", dh, NULL);
 	mgcidr = GNOME_DB_ENTRY_CIDR (obj);
