@@ -24,14 +24,11 @@
 #include <string.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtktable.h>
+#include <libgda/libgda.h>
 #include <libgnomedb/gnome-db-dsn-config.h>
 #include <libgnomedb/gnome-db-provider-selector.h>
 #include <libgnomedb/gnome-db-util.h>
-#include <libgnomedb/gnome-db-data-set.h>
-#include <libgnomedb/gnome-db-parameter.h>
 #include <libgnomedb/gnome-db-basic-form.h>
-#include <libgnomedb/gnome-db-server-data-type.h>
-#include <libgnomedb/gnome-db-data-handler.h>
 #include <glib/gi18n-lib.h>
 #include "gnome-db-dsn-spec.h"
 
