@@ -95,7 +95,7 @@ gnome_db_error_dialog_class_init (GnomeDbErrorDialogClass *klass)
 	/* add class properties */
 	g_object_class_install_property (
 		object_class, PROP_TITLE,
-		g_param_spec_string ("title", NULL, NULL, _("Error"),
+		g_param_spec_string ("title", NULL, _("Dialog's title"), _("Error"),
 				     (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 }
       
