@@ -31,6 +31,10 @@
 #include <libgnomeui/gnome-ui-init.h>
 #endif
 #include <gconf/gconf-client.h>
+#include <libgda/graph/gda-dict-reg-graphs.h>
+
+/* plugins list */
+GHashTable *gnome_db_plugins_hash = NULL; /* key = plugin name, value = GnomeDbPlugin structure pointer */
 
 extern void gnome_db_stock_init (void);
 
@@ -75,6 +79,9 @@ gnome_db_init (const gchar *app_id, const gchar *version, gint nargs, gchar *arg
 	if (!gconf_is_initialized ())
 		gconf_init (0, NULL, NULL);
 
+	/* make sure all the GdaDict object register GdaGraph */
+	gda_dict_class_always_register (gda_graphs_get_register);
+
 	initialized = TRUE;
 }
 
@@ -103,8 +110,11 @@ idle_cb (gpointer user_data)
  * @init_func: function to be called when everything has been initialized
  * @user_data: data to be passed to the init function
  *
- * You can specify a function to be called after everything has been correctly
- * initialized (that is, for initializing your own stuff).
+ * This function is a convenience function to specify a function to be called 
+ * after everything has been correctly
+ * initialized (that is, for initializing your own stuff), in an idle callback.
+ *
+ * Using it is not mandatory, and usually gtk_main() can be used.
  */
 void
 gnome_db_main_run (GdaInitFunc init_func, gpointer user_data)
@@ -119,11 +129,13 @@ gnome_db_main_run (GdaInitFunc init_func, gpointer user_data)
 		g_idle_add ((GSourceFunc) idle_cb, cb_data);
 	}
 
-	gtk_main();
+	gtk_main ();
 }
 
 /**
  * gnome_db_main_quit
+ *
+ * Convenience function, simply calls gtk_main_quit()
  */
 void
 gnome_db_main_quit (void)
