@@ -1,6 +1,6 @@
 /* gnome-db-selector.h
  *
- * Copyright (C) 2002 Vivien Malerba
+ * Copyright (C) 2002 - 2006 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,7 +22,8 @@
 #define __GNOME_DB_SELECTOR__
 
 #include <gtk/gtk.h>
-#include "gnome-db-dict.h"
+#include <libgda/gda-decl.h>
+#include "gnome-db-decl.h"
 
 G_BEGIN_DECLS
 
@@ -31,11 +32,6 @@ G_BEGIN_DECLS
 #define GNOME_DB_SELECTOR_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_selector_get_type (), GnomeDbSelectorClass)
 #define IS_GNOME_DB_SELECTOR(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_selector_get_type ())
 
-
-typedef struct _GnomeDbSelector      GnomeDbSelector;
-typedef struct _GnomeDbSelectorClass GnomeDbSelectorClass;
-typedef struct _GnomeDbSelectorPriv  GnomeDbSelectorPriv;
-
 typedef enum {
 	GNOME_DB_SELECTOR_DATA_TYPES  = 1 << 0,
 	GNOME_DB_SELECTOR_FUNCTIONS   = 1 << 1,
@@ -88,7 +84,7 @@ struct _GnomeDbSelectorClass
  * Generic widget's methods 
 */
 GType      gnome_db_selector_get_type            (void);
-GtkWidget *gnome_db_selector_new                 (GnomeDbDict *dict, GObject *ref_object, gulong mode, gulong columns);
+GtkWidget *gnome_db_selector_new                 (GdaDict *dict, GObject *ref_object, gulong mode, gulong columns);
 
 /*
  * Widget's manipulations
