@@ -446,7 +446,7 @@ compute_intersect_rect_line (gdouble rectx1, gdouble recty1, gdouble rectx2, gdo
  * Compute the anchor shapes to link field1 to field2 from ent1 to ent2
  */
 GSList *
-graph_util_compute_connect_shapes (GnomeDbCanvasEntity *ent1, GnomeDbField *field1, GnomeDbCanvasEntity *ent2, GnomeDbField *field2,
+graph_util_compute_connect_shapes (GnomeDbCanvasEntity *ent1, GdaEntityField *field1, GnomeDbCanvasEntity *ent2, GdaEntityField *field2,
 				   guint ext)
 {
 	GSList *retval;
