@@ -83,7 +83,7 @@ module_tables_fill_model (Module *module)
 	GdkPixbuf *pixbuf_table = NULL;
 
 	db = gda_dict_get_database (module->selector->priv->dict);
-	pixbuf_table = gnome_db_stock_get_icon_pixbuf_file ("gda-dict-table_16x16.png");
+	pixbuf_table = gnome_db_stock_get_icon_pixbuf_file ("gnome-db-table_16x16.png");
 
 	/* Module's private data */
 	module->mod_data = g_new0 (ModNameGroupData, 1);
